#ifndef NWNET_H
/*
 * Include file to be used by applications which link the DOS 3.X,
 * SPX Network Library
 *
 */

/*                                                                            */
/*                 Copyright 1987 Netwise, Inc.
*/
/*                            All Rights Reserved                             */
/*   This software contains information which is proprietary to and a trade   */
/*   secret  of  Netwise,  Inc.    It  is  not  to  be  used, reproduced
*    or  disclosed  except  as  authorized  in  your   license
/*   agreement.                                                               */
/*                          Restricted Rights Legend                          */
/*   Use, duplication,  or  disclosure  by the  Government  is  subject  to   */
/*   restrictions as set forth in subparagraph (c)(1)(ii) of the Rights  in   */
/*   Technical Data and  Computer Software clause  at 252.227-7013, or  the   */
/*   equivalent Government clause for other agencies.                         */
/*   Contractor: Netwise, Inc., Boulder, CO 80301 USA
*/
/*
 * char rcsid[] = "$Header$";
 */

/*
 * $Log$
 */

/* Get the required system include files */

#ifndef NULL
#include <stdio.h>
#endif

typedef struct nl_info {                /* Passed in to and out of nl_init */
        unsigned max_len;
        unsigned short  addr_len;
};

typedef struct nl_stats {               /* Passed out of nl_status */
        int     connected;
        int     listening;
        int     read_ready;
        int     errored;
};

/* Select condition types */
#define CONNECTED 1
#define READ_READY 2
#define LISTENING 3
#define ERRORED 4

typedef int connection_id;              /* Users see id's as integer type */
#define INVALID_ID      -1

extern int _nl_error_;

/* Declarations for library routines, for type checking */
extern int
  nl_init(struct nl_info *);

extern int
  nl_find(char *, char *, unsigned short *);

extern int
  nl_getaddr(char *, unsigned short *);

extern int
  nl_open(connection_id *);

extern int
  nl_register(char *, char *,
                unsigned short *, connection_id );

extern int
  nl_listen(char *, unsigned short *, connection_id);

extern int
  nl_addna(char *, char *, unsigned short *);

extern int
  nl_accept(connection_id, connection_id,
                char *, unsigned short *);

extern int
  nl_connect(char *, unsigned short, connection_id);

extern int
  nl_close(connection_id);

extern int
  nl_abort(connection_id);

extern int
  nl_send(connection_id, char *, unsigned);

extern int
  nl_receive(connection_id, char *,
                unsigned, unsigned *);

extern int
  nl_call(connection_id,
                char *, unsigned,
                char *, unsigned,
                unsigned *);

extern int
  nl_oneshot(char *, unsigned short,
                char *, unsigned,
                char *, unsigned,
                unsigned *);

extern int
  nl_status(connection_id, struct nl_stats *);

extern int
  nl_select(connection_id *, int, int, int *);

/* Non-Error Returns */
#define NSUCC           0       /* Successful Return */
#define IMOREDATA       502     /* More Data Indication */
#define IALRINIT        504     /* Network Library already initialized */

/* General Error Codes */
#define ENOTINIT        501     /* Network Library not initialized */
#define EINVALID        503     /* Invalid connection identifier */
#define ETOOBIG         505     /* Server name or Address too long */
#define EBADFMT         507     /* Bad format Server name or Address */
#define ESHORTBUF       509     /* Address buffer too short */
#define ENOCONNIDS      511     /* No more connection id's available */
#define ENOMATCH        513     /* Address doesn't match */
#define EALRUSED        515     /* Service name already in use */
#define EBADARG         517     /* Bad argument */
#define ERETRY          519     /* Accept can be retried */
#define ECLOSED         521     /* Read from a closed connection */
#define EINTRNL         523     /* Detected internal consistency failure */
#define EINTRRPT        525     /* Network Library call was interrupted */
#define EUNAVAIL        527 /* Service is not currently available */
#define ENOREGIS        529 /* No more registrations possible */
#define ENOTFOUND       531     /* Server name not found */
#define EINVSTATE       533 /* Endpoint in incorrect state */
#define EPDUOVF         535 /* Requested PDU length is too large */

/* SPX implementation error codes */
#define ELSTCON  601       /* SPXListenForConnection failed                   */
#define ELSTPKT  603       /* SPXListenForSequencedPacket failed              */
#define ESNDPKT  605       /* SPXSendSequeuncedPacket failed                  */
#define ETRMCON  607       /* SPXTerminateConnection failed                   */
#define EOPNSOC  609       /* IPXOpenSocket failed                            */
#define EDELOBJ  611       /* DeleteBinderyObject failed                      */
#define EESTCON  613       /* SPXEstablishConnection failed                   */
#define ERDPROP  615       /* ReadPropertyValue failed                        */
#define ESPXINI  617       /* SPXInitialize failed                            */
#define ECRTOBJ  619       /* CreateBinderyObject failed                      */
#define ECRPROP  621       /* CreateProperty failed                           */
#define EWRPROP  623       /* WritePropertyValue failed                       */

#define ENOMEMY  625       /* Insufficient memory allocated for operation     */
#define ERECTIM  627       /* Attempt to reconnect to client timed out        */


/* Values that may appear in nl_error, in addition to SPX errors              */
#define EWATCHD  200       /* Watchdog timer indicated connection failed      */
#define EENDCON  201       /* The other side has terminated the connection    */
#define EABORT   202       /* The other side has aborted the connection       */

#define NWNET_H
#endif
